/********************************************************************************
 Author : 

 Date :   August 1, 2014

 File name :  ad7989.c

 Description :	 Define the different modes AD7989.

 Hardware plateform : 	AD7989 & ADuCM360
********************************************************************************/

#include <ADuCM360.h>

#include "..\common\UrtLib.h"
#include "..\common\ClkLib.h"
#include "..\common\WdtLib.h"
#include "..\common\IntLib.h"
#include "..\common\DioLib.h"
#include "..\common\SpiLib.h"

#include "AD7989.h"

void ConversionDelay(void)
{
    char i;
    for(i=0; i<1; i++);
}

/********************************************************************************
Function Name : CSmode_3Wire

Description : ADC1 CS Mode, 3 Wire using SPI0 in Port 1.

Connection :
						SDI <--- Viox or P1.2
						SCK <--- SPI0 SCLK (P1.5)
						SDO1 ---> SPI MISO (P1.4)
						CNV1 <--- P1.3

Note: Please refer to AD7902 datasheet for connection diagram.
********************************************************************************/

unsigned int CSmode_3Wire(void)
{
    int ReadData;
    char i;
    unsigned int ADCTemp[3];

    DioSet(pADI_GP1, SDI); //Set SDI to High
		DioClr(pADI_GP1, CNV); //Set CNV to Low
		DioSet(pADI_GP1, CNV); //Create a rising edge at CNV to initiate conversion
		ConversionDelay();			//Delay for conversion to finish
		DioClr(pADI_GP1, CNV); //Create a falling edge at CNV1 to allow data readback after conversion     
	
    for (i=0; i<3; i++)                                     
    {
        SpiFifoFlush(pADI_SPI0,SPICON_TFLUSH_DIS,SPICON_RFLUSH_EN); //Flush Rx to FIFO
        SpiTx(pADI_SPI0,0x00);																			//Write 0x00 to SPIxTX.
        while ((SpiSta(pADI_SPI0) & 0x0020)!=0x0000); 							//Wait until SPI Tx IRQ status bit is 0.			
        while((SpiSta(pADI_SPI0) & 0x0100)!=0x0100);  							//SPI Rx FIFO status bits. Wait until there is one valid byte in the FIFO.
        ADCTemp[i] = SpiRx(pADI_SPI0); 															//Write one byte in ADCTemp[i].
    }  
		
		//Write the temporary data to ReadData.
    ReadData = ADCTemp[0];
    ReadData = (ReadData<<8) + ADCTemp[1];
		ReadData = (ReadData<<8) + (ADCTemp[2] & 0xC0);
		ReadData = ((ReadData>>6) & 0x03FFFF);
		
 
    DioSet(pADI_GP1, CNV); //Set CNV to High.
		//DioClr(pADI_GP1, CNV); //Set CNV to Low.
    return(ReadData);	//Return ReadData to Function
}
